==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/DESTINATIONVALUEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour DESTINATIONVALUEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="DESTINATIONVALUEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESTINATIONVALUE1" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESTINATIONVALUE2" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DESTINATIONVALUEID_Type", propOrder = {
    "destinationvalue1",
    "destinationvalue2"
})
public class DESTINATIONVALUEID_Type {

    @XmlElement(name = "DESTINATIONVALUE1")
    protected String destinationvalue1;
    @XmlElement(name = "DESTINATIONVALUE2")
    protected String destinationvalue2;

    /**
     * Obtient la valeur de la propriété destinationvalue1.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESTINATIONVALUE1() {
        return destinationvalue1;
    }

    /**
     * Définit la valeur de la propriété destinationvalue1.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESTINATIONVALUE1(String value) {
        this.destinationvalue1 = value;
    }

    /**
     * Obtient la valeur de la propriété destinationvalue2.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESTINATIONVALUE2() {
        return destinationvalue2;
    }

    /**
     * Définit la valeur de la propriété destinationvalue2.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESTINATIONVALUE2(String value) {
        this.destinationvalue2 = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/DESTINATIONVALUEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DESTINATIONVALUEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DESTINATIONVALUEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESTINATIONVALUE1" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESTINATIONVALUE2" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DESTINATIONVALUEID_Type", propOrder = {
    "destinationvalue1",
    "destinationvalue2"
})
public class DESTINATIONVALUEID_Type {

    @XmlElement(name = "DESTINATIONVALUE1")
    protected String destinationvalue1;
    @XmlElement(name = "DESTINATIONVALUE2")
    protected String destinationvalue2;

    /**
     * Gets the value of the destinationvalue1 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESTINATIONVALUE1() {
        return destinationvalue1;
    }

    /**
     * Sets the value of the destinationvalue1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESTINATIONVALUE1(String value) {
        this.destinationvalue1 = value;
    }

    /**
     * Gets the value of the destinationvalue2 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESTINATIONVALUE2() {
        return destinationvalue2;
    }

    /**
     * Sets the value of the destinationvalue2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESTINATIONVALUE2(String value) {
        this.destinationvalue2 = value;
    }

}
